Ropecon Ropecon 2005, Espoo, Finland July 22nd 2005 85 players Jarkko Suvela With a feminine touch Crypt (13 cards, min=15, max=43, avg=8.15) ------------------------------------------ 3x Stanislava 11 ANI CEL DOM FOR PRO inner circle Gangrel:2 2x Genevieve 10 ANI FOR PRO aus dom priscus Gangrel antitribu:2 2x Rachel Brandywine 10 AUS DEM OBF PRO ani prince Malkavian:3 2x Ingrid Rossler 9 ANI FOR PRO dom prince Gangrel:2 1x Caitlin 6 ANI PRO aus dom bishop Gangrel antitribu:2 1x Bothwell 3 ani for Gangrel:3 1x Chandler Hungerford 3 PRO Gangrel:2 1x Panagos Levidis 3 ani obf Gangrel:2 Library (90 cards) Master (17) 3x Blood Doll 1x Direct Intervention 1x Dominate 2x Dreams of the Sphinx 1x Ecoterrorists 1x Giant's Blood 2x Golconda: Inner Peace 5x Minion Tap 1x Sudden Reversal Ally (1) 1x Ossian Equipment (2) 1x Assault Rifle 1x Palatial Estate Political Action (20) 1x Alastor 1x Ancient Influence 2x Banishment 1x Disputed Territory 1x Gangrel Justicar 5x Kine Resources Contested 2x Parity Shift 1x Political Stranglehold 1x Protect Thine Own 4x Reinforcements 1x Reins of Power Retainer (2) 1x J. S. Simmons, Esq. 1x Tasha Morgan Action Modifier (16) 3x Beast Meld 3x Conditioning 4x Earth Control 6x Freak Drive Action Modifier/Combat (3) 3x Rapid Change Reaction (14) 7x Deflection 2x Guard Dogs 2x Rat's Warning 3x Wake with Evening's Freshness Combat (15) 3x Carrion Crows 5x Earth Meld 4x Form of Mist 3x Superior Mettle